@@ -21,13 +21,14 @@ import re
 from funing._fui import error
 import numpy as np
 from cv2 import haarcascades
+import webbrowser
 
 class _MainUI():
     def __init__(self):
         self.mainui = MainUI()
         self.mainui.place()
         self.source = 0
-        self.root_after = -1        
+        self.root_after = -1
         # face num for face_label
         self.lang_code = settings.lang_code
         self.fxfy = None        
@@ -35,8 +36,9 @@ class _MainUI():
         self.video_exts = ['mp4','avi','3gp','webm','mkv']
         self.showf_sv = None
         self.showfm = self.mainui.showframe
-        self.entryfm = self.mainui.entryframe
-        self.infofm = self.mainui.infoframe   
+        self.infofm = self.mainui.infoframe
+        self.rbmixfm = self.mainui.rbmixframe        
+        self.about_tl = None
         # vid
         self.vid = None
         self.vid_width = 0
@@ -53,7 +55,6 @@ class _MainUI():
         # info
         self.cur_info_id = None
         self.info_ids = []
-        # self.rec_results = []
         # cv2
         self.hff_xml_path = os.path.join( haarcascades ,\
          "haarcascade_frontalface_default.xml" )
@@ -92,6 +93,26 @@ class _MainUI():
         images=np.asarray(images)
         labels=np.asarray(labels)
         return images,labels,ids
+    
+    def about_fn(self):
+        if self.about_tl == None:
+            self.about_tl = Toplevel(borderwidth = 10)
+            self.about_tl.title(_('About Funing'))
+            self.about_tl.resizable(0,0)
+            Label( self.about_tl, text =_('Funing'), font=("", 25)).pack()
+            Label(  self.about_tl, text = settings.version ).pack()
+            self.source_page_label = Label(self.about_tl,text=\
+            settings.source_page,fg="blue", cursor="hand2")
+            self.source_page_label.bind("<Button-1>",lambda e: \
+            webbrowser.open_new(settings.source_page ))
+            self.source_page_label.pack()
+            Label(self.about_tl,text=_('Licensed under the MIT license') )\
+            .pack()
+            self.about_tl.mainloop()
+        else:
+            self.about_tl.destroy()
+            self.about_tl = None
+        pass
 
     def recognizer_train( self ):
         images,labels,self.info_ids = self.load_images()
@@ -110,7 +131,7 @@ class _MainUI():
         self.vid= None  
     
     def set_ui_events( self ):
-        self.mainui.langcombobox.lang_combobox.bind('<<ComboboxSelected>>',
+        self.rbmixfm.lang_combobox.bind('<<ComboboxSelected>>',
             self.change_language )
         self.showfm.ct_entry.bind('<FocusOut>', None )
         self.showfm.pp_btn['command'] = self.pause_play
@@ -120,6 +141,7 @@ class _MainUI():
         self.infofm.prevf_btn['command'] = self.prevf
         self.infofm.nextf_btn['command'] = self.nextf
         self.infofm.save_btn['command'] = self.savef
+        self.rbmixfm.about_fn_btn['command'] = self.about_fn
         self.mainui.root.protocol("WM_DELETE_WINDOW", self.destroy )
          
     def destroy( self ):
@@ -131,22 +153,22 @@ class _MainUI():
 
     def pause_play( self, *args ):
         if self.pause: 
-            self.pause = False
             if self.vid is None: return
-            self.root_after_cancel()
             if settings.data_empty(): 
                 if settings.debug: print('data is empty!')
                 self.show_data_empty_error()
                 return
+            self.root_after_cancel()
             if self.cur_frame is None: return
             self.recf()
-            self.showfm.pp_sv.set( _('Play') )
+            self.showfm.pr_sv.set( _('Play') )
+            self.pause = False
             # self.pick()
         else:
-            self.pause = True
             if self.cur_frame is None: return
             self.refresh_frame()
-            self.showfm.pp_sv.set( _('Recognize') )
+            self.showfm.pr_sv.set( _('Recognize') )
+            self.pause = True
 
     def pick(self):
         if self.vid is None: return
@@ -166,10 +188,13 @@ class _MainUI():
                 self.face_frames.append( new_frame )
                 count+=1
                 if count > self.face_enter_count: break
+        
+        self.infofm.faces_text.delete(1.0,tk.END)
         self.change_face_show(0)
     
     def show_go( self, *args ):
         self.showf_sv = self.showfm.showf_sv.get()
+        if len( self.showf_sv.strip() ) < 1: return
         self.rec_img = False
         self.root_after_cancel()
         showf_ext = self.showf_sv.split('.')[-1]
@@ -273,13 +298,6 @@ class _MainUI():
 ###############################################################################
 # SHOW_FRAME FUNCTIONS END
 
-# ENTRY_FRAME FUNCTIONS
-###############################################################################
-
-        
-###############################################################################
-# ENTRY_FRAME FUNCTIONS END
-
 # INFO_FRAME FUNCTIONS
 ###############################################################################
 
@@ -305,9 +323,14 @@ class _MainUI():
         self.cur_info_id = None
         if settings.debug:print( 'info > ' + info )
         self.recognizer_train()
+    
+    def update_num_label(self):
+        self.infofm.num_label['text'] = \
+        f'{self.curf_index+1}/{len(self.face_frames)+len(self.recfs)-1}'
             
     def change_face_show(self, _as):
         if len(self.face_frames) >0:
+            # NEW
             self.curf_index += _as
             self.curf_index = 0 if self.curf_index < 0 else self.face_enter_count-1\
             if self.curf_index >= self.face_enter_count else self.curf_index 
@@ -317,7 +340,10 @@ class _MainUI():
             imgtk = ImageTk.PhotoImage( image=vid_img )
             self.infofm.curf_label.imgtk = imgtk
             self.infofm.curf_label.configure(image=imgtk)
+            self.update_num_label()
+
         elif len(self.recfs) > 0:
+            # RECOGNIZE
             _len = len( self.recfs )
             self.curf_index+=_as
             self.curf_index = 0 if self.curf_index < 0 else _len - 1\
@@ -329,7 +355,9 @@ class _MainUI():
             interpolation=cv2.INTER_LINEAR)
             result=self.recognizer.predict(roi_gray)
             _id = self.info_ids[result[0]]
-            frame = self.cur_frame[y:y+h,x:x+w] 
+            _h = h if h>w else w
+            frame = self.cur_frame[y:y+_h,x:x+_h]
+            frame = cv2.resize(frame, (200,200))
 
             vid_img = cv2.cvtColor( frame, cv2.COLOR_BGR2RGB )
             vid_img = Image.fromarray( vid_img  )
@@ -342,6 +370,7 @@ class _MainUI():
             self.infofm.faces_text.delete(1.0,tk.END)
             self.infofm.faces_text.insert('1.0', \
             open( info_file_path, 'r' ).read() )
+            self.update_num_label()
     
     def recf(self):
         self.face_frames = []
@@ -356,10 +385,6 @@ class _MainUI():
             self.cur_frame=cv2.rectangle(\
             self.cur_frame,(x,y),(x+w,y+h),(255,0,0),2)  
         self.cur_frame2label()
-
-
-
-
              
 ###############################################################################
 # INFO_FRAME FUNCTIONS  END
@@ -369,7 +394,7 @@ class _MainUI():
 
     def change_language(self, lang ):
 
-        lang_display_name = self.mainui.langcombobox.lang_combobox_var.get()
+        lang_display_name = self.rbmixfm.lang_combobox_var.get()
         new_lang_code = Language.find( lang_display_name ).to_tag()
         if settings.debug:
             print( 'new_lang_code: ', new_lang_code, \
@@ -382,7 +407,7 @@ class _MainUI():
         )
         if restartapp:
             settings.config_yml['lang_code'] = new_lang_code
-            yaml.dump( settings.config_yml, open( settings.config_path, 'w') )
+            yaml.dump( settings.config_yml, open( settings._config_path, 'w') )
             sys_executable = sys.executable
             os.execl(sys_executable, sys_executable, * sys.argv)
         pass
